@@ -55,104 +55,103 @@ module test;
   assign _axi_bready = 1;
   assign _axi_arcache = 3;
   assign _axi_arprot = 0;
-  reg [3-1:0] outstanding_wcount_0;
-  wire [32-1:0] _tmp_1;
-  assign _tmp_1 = _axi_awaddr;
+  wire [32-1:0] _tmp_0;
+  assign _tmp_0 = _axi_awaddr;
 
   always @(*) begin
-    myaxi_awaddr = _tmp_1;
+    myaxi_awaddr = _tmp_0;
   end
 
-  wire [4-1:0] _tmp_2;
-  assign _tmp_2 = _axi_awcache;
+  wire [4-1:0] _tmp_1;
+  assign _tmp_1 = _axi_awcache;
 
   always @(*) begin
-    myaxi_awcache = _tmp_2;
+    myaxi_awcache = _tmp_1;
   end
 
-  wire [3-1:0] _tmp_3;
-  assign _tmp_3 = _axi_awprot;
+  wire [3-1:0] _tmp_2;
+  assign _tmp_2 = _axi_awprot;
 
   always @(*) begin
-    myaxi_awprot = _tmp_3;
+    myaxi_awprot = _tmp_2;
   end
 
-  wire _tmp_4;
-  assign _tmp_4 = _axi_awvalid;
+  wire _tmp_3;
+  assign _tmp_3 = _axi_awvalid;
 
   always @(*) begin
-    myaxi_awvalid = _tmp_4;
+    myaxi_awvalid = _tmp_3;
   end
 
   assign _axi_awready = myaxi_awready;
-  wire [32-1:0] _tmp_5;
-  assign _tmp_5 = _axi_wdata;
+  wire [32-1:0] _tmp_4;
+  assign _tmp_4 = _axi_wdata;
 
   always @(*) begin
-    myaxi_wdata = _tmp_5;
+    myaxi_wdata = _tmp_4;
   end
 
-  wire [4-1:0] _tmp_6;
-  assign _tmp_6 = _axi_wstrb;
+  wire [4-1:0] _tmp_5;
+  assign _tmp_5 = _axi_wstrb;
 
   always @(*) begin
-    myaxi_wstrb = _tmp_6;
+    myaxi_wstrb = _tmp_5;
   end
 
-  wire _tmp_7;
-  assign _tmp_7 = _axi_wvalid;
+  wire _tmp_6;
+  assign _tmp_6 = _axi_wvalid;
 
   always @(*) begin
-    myaxi_wvalid = _tmp_7;
+    myaxi_wvalid = _tmp_6;
   end
 
   assign _axi_wready = myaxi_wready;
   assign _axi_bresp = myaxi_bresp;
   assign _axi_bvalid = myaxi_bvalid;
-  wire _tmp_8;
-  assign _tmp_8 = _axi_bready;
+  wire _tmp_7;
+  assign _tmp_7 = _axi_bready;
 
   always @(*) begin
-    myaxi_bready = _tmp_8;
+    myaxi_bready = _tmp_7;
   end
 
-  wire [32-1:0] _tmp_9;
-  assign _tmp_9 = _axi_araddr;
+  wire [32-1:0] _tmp_8;
+  assign _tmp_8 = _axi_araddr;
 
   always @(*) begin
-    myaxi_araddr = _tmp_9;
+    myaxi_araddr = _tmp_8;
   end
 
-  wire [4-1:0] _tmp_10;
-  assign _tmp_10 = _axi_arcache;
+  wire [4-1:0] _tmp_9;
+  assign _tmp_9 = _axi_arcache;
 
   always @(*) begin
-    myaxi_arcache = _tmp_10;
+    myaxi_arcache = _tmp_9;
   end
 
-  wire [3-1:0] _tmp_11;
-  assign _tmp_11 = _axi_arprot;
+  wire [3-1:0] _tmp_10;
+  assign _tmp_10 = _axi_arprot;
 
   always @(*) begin
-    myaxi_arprot = _tmp_11;
+    myaxi_arprot = _tmp_10;
   end
 
-  wire _tmp_12;
-  assign _tmp_12 = _axi_arvalid;
+  wire _tmp_11;
+  assign _tmp_11 = _axi_arvalid;
 
   always @(*) begin
-    myaxi_arvalid = _tmp_12;
+    myaxi_arvalid = _tmp_11;
   end
 
   assign _axi_arready = myaxi_arready;
   assign _axi_rdata = myaxi_rdata;
   assign _axi_rresp = myaxi_rresp;
   assign _axi_rvalid = myaxi_rvalid;
-  wire _tmp_13;
-  assign _tmp_13 = _axi_rready;
+  wire _tmp_12;
+  assign _tmp_12 = _axi_rready;
 
   always @(*) begin
-    myaxi_rready = _tmp_13;
+    myaxi_rready = _tmp_12;
   end
 
   reg [32-1:0] fsm;
@@ -191,12 +190,6 @@ module test;
   );
 
 
-  initial begin
-    $dumpfile("uut.vcd");
-    $dumpvars(0, uut, CLK, RST, myaxi_awaddr, myaxi_awcache, myaxi_awprot, myaxi_awvalid, myaxi_awready, myaxi_wdata, myaxi_wstrb, myaxi_wvalid, myaxi_wready, myaxi_bresp, myaxi_bvalid, myaxi_bready, myaxi_araddr, myaxi_arcache, myaxi_arprot, myaxi_arvalid, myaxi_arready, myaxi_rdata, myaxi_rresp, myaxi_rvalid, myaxi_rready, _axi_awaddr, _axi_awcache, _axi_awprot, _axi_awvalid, _axi_awready, _axi_wdata, _axi_wstrb, _axi_wvalid, _axi_wready, _axi_bresp, _axi_bvalid, _axi_bready, _axi_araddr, _axi_arcache, _axi_arprot, _axi_arvalid, _axi_arready, _axi_rdata, _axi_rresp, _axi_rvalid, _axi_rready, outstanding_wcount_0, _tmp_1, _tmp_2, _tmp_3, _tmp_4, _tmp_5, _tmp_6, _tmp_7, _tmp_8, _tmp_9, _tmp_10, _tmp_11, _tmp_12, _tmp_13, fsm, sum, __axi_cond_0_1, __axi_cond_1_1);
-  end
-
-
   initial begin
     CLK = 0;
     forever begin
@@ -214,7 +207,6 @@ module test;
     _axi_wvalid = 0;
     _axi_araddr = 0;
     _axi_arvalid = 0;
-    outstanding_wcount_0 = 0;
     fsm = fsm_init;
     sum = 0;
     __axi_cond_0_1 = 0;
@@ -230,7 +222,6 @@ module test;
 
   always @(posedge CLK) begin
     if(RST) begin
-      outstanding_wcount_0 <= 0;
       _axi_awaddr <= 0;
       _axi_awvalid <= 0;
       _axi_wdata <= 0;
@@ -247,12 +238,6 @@ module test;
       if(__axi_cond_1_1) begin
         _axi_arvalid <= 0;
       end 
-      if(_axi_wvalid && _axi_wready && !(_axi_bvalid && _axi_bready) && (outstanding_wcount_0 < 7)) begin
-        outstanding_wcount_0 <= outstanding_wcount_0 + 1;
-      end 
-      if(!(_axi_wvalid && _axi_wready) && (_axi_bvalid && _axi_bready) && (outstanding_wcount_0 > 0)) begin
-        outstanding_wcount_0 <= outstanding_wcount_0 - 1;
-      end 
       _axi_awaddr <= 0;
       _axi_awvalid <= 0;
       _axi_wdata <= 0;
@@ -361,19 +346,19 @@ module main
   assign myaxi_wready = 0;
   reg [32-1:0] fsm;
   localparam fsm_init = 0;
-  reg [32-1:0] addr_0;
-  reg valid_1;
-  reg prev_arvalid_2;
-  assign myaxi_arready = (fsm == 0) && !valid_1 && prev_arvalid_2;
+  reg [32-1:0] _tmp_0;
+  reg _tmp_1;
+  reg _tmp_2;
+  assign myaxi_arready = (fsm == 0) && !_tmp_1 && _tmp_2;
   reg [32-1:0] rdata;
   reg _myaxi_cond_0_1;
 
   always @(posedge CLK) begin
     if(RST) begin
       myaxi_bvalid <= 0;
-      prev_arvalid_2 <= 0;
-      addr_0 <= 0;
-      valid_1 <= 0;
+      _tmp_2 <= 0;
+      _tmp_0 <= 0;
+      _tmp_1 <= 0;
       myaxi_rdata <= 0;
       myaxi_rvalid <= 0;
       _myaxi_cond_0_1 <= 0;
@@ -387,11 +372,11 @@ module main
       if(myaxi_wvalid && myaxi_wready) begin
         myaxi_bvalid <= 1;
       end 
-      prev_arvalid_2 <= myaxi_arvalid;
+      _tmp_2 <= myaxi_arvalid;
       if(myaxi_arready && myaxi_arvalid) begin
-        addr_0 <= myaxi_araddr;
+        _tmp_0 <= myaxi_araddr;
       end 
-      valid_1 <= myaxi_arready && myaxi_arvalid;
+      _tmp_1 <= myaxi_arready && myaxi_arvalid;
       if((fsm == 1) && (myaxi_rready || !myaxi_rvalid)) begin
         myaxi_rdata <= rdata;
         myaxi_rvalid <= 1;
@@ -413,10 +398,10 @@ module main
     end else begin
       case(fsm)
         fsm_init: begin
-          if(valid_1) begin
-            rdata <= addr_0 >> 2;
+          if(_tmp_1) begin
+            rdata <= _tmp_0 >> 2;
           end 
-          if(valid_1) begin
+          if(_tmp_1) begin
             fsm <= fsm_1;
           end 
         end
